
# Lecture 8 – Magnetism

_Based on chapters 19 and 20 of the book_

In this lecture we will:

- discuss common forms of magnetism
- introduce magnetic susceptibility
- discuss Hund's rules
- discuss magnetic order

### Magnetic field
To start off confusing, there are two different quantities that are often referred to as the _magnetic field_: the ${\bf B}$-field (in units of Tesla) and the ${\bf H}$-field (in A/m). In vacuum, they are proportional:

$$
{\bf B}=\mu_0 {\bf H}
$$

with $\mu_0$ the permeability of free space. Technically, inside a material they differ. Here, ${\bf B}$ is the total magnetic field that one can measure locally, while ${\bf H}$ is the same, but corrected for the magnetisation:

$$
{\bf B}=\mu_0({\bf H}+{\bf M}),\ {\rm or}\ \ {\bf H}=\frac{\bf B}{\mu_0}-{\bf M}
$$

where ${\bf M}$ is the _magnetisation_. In other words, ${\bf B}$ is the field due to free currents and 'bound currents' (i.e. local magnetised moments) while ${\bf H}$ is the field due only to free currents. But in practice, ${\bf M}$ is small compared to ${\bf H}$, so we always assume ${\bf B}=\mu_0 {\bf H}$.

### Magnetic susceptibility
The _susceptibility_ $\chi$ is the extent to which a material is prone to magnetisation:

$$
{\bf M}=\chi{\bf H}=\chi\frac{\bf B}{\mu_0}
$$

Depending on the sign, you can get different forms of magnetism:

$\chi>0\rightarrow$ _paramagnetism_: the material tends to magnetise along the local field.

$\chi<0\rightarrow$ _diamagnetism_: the material tends to magnetise opposite to the local field.

Further on, we will discuss two forms of spontaneous magnetisation: _ferromagnetism_ and _anti-ferromagnetism_. Unlike the ones mentioned above, these forms persist even in the absense of a magnetic field.

### Hund's rules
We discussed before that the magnetic configuration of electrons in an atomic orbital can be described with four quantum numbers: $n$, $l$, $l_z$ and $\sigma_z$. Question is: how do these spin and orbital momental align inside the atom? There are various mechanism governing this, but the results can be summarized in three _Hund's rules_:

- Rule 1: Maximise $S$.
- Rule 2: Maximise $L$ (provided that rule 1 is satisfied).
- Rule 3: For shells less than half filled: $J=|L-S|$. For shells more than half filled: $J=L+S$.

Examples:

- Fe = [Ar]4s$^2$3d$^6$

$S=2$, $L=2$, $J=4$ $\rightarrow$ $^{2S+1}L_J =\ ^5{\rm D}_4$

- V = [Ar]4s$^2$3d$^3$

$S=\frac{3}{2}$, $L=3$, $J=\frac{3}{2}$ $\rightarrow$ $^{2S+1}L_J =\ ^4{\rm F}_{3/2}$

![](figures/hund.svg)

### Paramagnetism: free spin $\frac{1}{2}$
If single electron spin ${\bf \sigma}$ is situated in a magnetic field ${\bf B}$, it can be described by the Zeeman Hamiltonian (note convention minus sign):

$$
{\mathcal H}=g\mu_{\rm B}{\bf B}\cdot{\bf \sigma}
$$

where $\mu_{\rm B}=\frac{e\hbar}{2m_{\rm e}}=10^{-23}$ J/T is the _Bohr magneton_ and $g$ is the _g-factor_, which for an electron is almost exactly 2. Its two eigenstates are $+\mu_{\rm B}B$ and $-\mu_{\rm B}B$. The statistical magnetisation for $n$ spins can be found using the Boltzmann distribution:

$$
M=n\frac{\mu_{\rm B}{\rm e}^{-\beta\mu_{\rm B}B}-\mu_{\rm B}{\rm e}^{+\beta\mu_{\rm B}B}}{{\rm e}^{-\beta\mu_{\rm B}B}+{\rm e}^{+\beta\mu_{\rm B}B}}=n\mu_{\rm B}{\rm tanh}(\beta\mu_{\rm B}B)
$$

For small $B$ this function is linear, allowing us to extract the susceptibility

$$
\chi=\mu_0\frac{{\rm d}M}{{\rm d}B}\approx\frac{n\mu_0 \mu_{\rm B}^2}{k_{\rm B}T}=\frac{C}{k_{\rm B}T}
$$

with $C$ a constant. This is known as the _Curie law_, and it shows that at high temperature a paramagnetic material becomes less susceptible to magnetisation.

![](figures/curie.svg)

### Paramagnetism: free spin $J$
For an atom with magnetic moments $L$ and $S$ the Hamiltonian will become:

$$
{\mathcal H}=\mu_{\rm B}{\bf B}\cdot\left({\bf L}+g{\bf S}\right)
$$

This can be written in terms of the total magnetic moment ${\bf J}$ using the _Landé factor_ $\tilde{g}\ $:

$$
{\mathcal H}=\tilde{g}\ \mu_{\rm B}{\bf B}\cdot{\bf J}
$$

with

$$
\tilde{g}\ =\frac{1}{2}(g+1)+\frac{1}{2}(g-1)\left[\frac{S(S+1)-L(L+1)}{J(J+1)}\right]=\frac{3}{2}-\frac{L(L+1)-S(S+1)}{2J(J+1)}
$$

The result is a ladder of equally spaced levels. The bigger the contribution of $S$ inside $J$, the bigger te level spacing.

![](figures/lande.svg)

Now, the magnetisation for $n$ atoms becomes:

$$
M=n\frac{\sum_{m_{J}=-J}^{J}\tilde{g}\ \mu_{\rm B}m_{J}{\rm e}^{-\beta\mu_{\rm B}m_J B}}{\sum_{m_{J}=-J}^{J}{\rm e}^{-\beta\mu_{\rm B}m_J B}}
$$

The resulting susceptibility is:

$$
\chi=\frac{n\mu_0(\tilde{g}\ \mu_{\rm B})^2}{3}\frac{J(J+1)}{k_{\rm B}T}
$$